// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Pdf.Annotations;
using System.Collections.Generic;
using GrapeCity.Documents.Common;

namespace DsPdfWeb.Demos
{
    // このサンプルでは、PDF ドキュメント内の単語をすべて検索し、検索結果すべてを
    // テキストマークアップ注釈のハイライトを使用して強調表示する方法を紹介しています。
    // なお、ここでは、単語ごとにテキストマークアップ注釈を作成します。MarkupPerPage では、
    // 別の方法として、ページごとにテキストマークアップ注釈を作成しています。
    public class FindAndHighlight
    {
        public int CreatePDF(Stream stream)
        {
            // PDF を読み込みます。
            var doc = new GcPdfDocument();
            using var fs = File.OpenRead(Path.Combine("Resources", "PDFs", "diodocs_flyer.pdf"));
            doc.Load(fs);

            // 単語「.NET」をすべて検索します。
            var found = doc.FindText(new FindTextParams(".NET", true, false), null);

            // テキストマークアップ注釈を追加し、検索結果すべてをハイライトします。
            foreach (var f in found)
            {
                var markup = new TextMarkupAnnotation()
                {
                    Page = doc.Pages[f.PageIndex],
                    MarkupType = TextMarkupType.Highlight,
                    Color = Color.Yellow
                };
                List<Quadrilateral> area = new List<Quadrilateral>();
                foreach (var b in f.Bounds)
                    area.Add(b);
                markup.Area = area;
            }

            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
